bones.http.auth


check-authenticatedclj

source

check-passwordclj

(check-password password-candidate encrypted-password)
source

encrypt-passwordclj

(encrypt-password password)
source

gen-secretclj

(gen-secret)
(gen-secret n)

printable secret, so it can be put into a text file

printable secret, so it can be put into a text file
sourceraw docstring

limited-secretclj

(limited-secret secret n)
source

Tokencljprotocol

tokenclj

(token this data)
source

validate-secretclj

(validate-secret secret algorithm)
source

cljdoc builds & hosts documentation for Clojure/Script libraries